Crate deimos_shared

Deimos - Shared Module

Packet formats and byte-serialization for the Deimos data acquisition ecosystem.

See the project readme for contact details as well as commentary about the goals and state of the project.

This library is shared with both the peripheral firmware and the control program so that critical data structures and constants maintain parity at all times.

Re-exports

pub use states::OperatingMetrics;

Modules

peripherals
states
I/O formatting for each peripheral state.

Macros

enum_with_unknown
Derive To/From with an added “Unknown” variant catch-all for converting from numerical values that do not match a valid variant in order to avoid either panicking or cumbersome error handling.

Constants

CONTROLLER_RX_PORT
The UDP port on which the control machine expects to receive packets from hardware peripherals
PERIPHERAL_RX_PORT
The UDP port on which the hardware peripherals expect to receive packets from the control machine